/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.federation.service;

import java.util.Collection;

/**
 * A Federation Service represents the SSO Federation Service. A SSO Federation Service is a key component for SSO token propogation across partner sites 
 * especially those located in different security domains. 
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - May 28, 2006
 *
 */
public interface FederationService 
{
    /**
     * Returns a collection of partner web applications that are part of this SSO Federation
     * 
     * @return partner web applications that belong to the Single Sign On Federation
     */
    public Collection getPartners();
    
    /**
     * Returns an xml representation of partner web applications that are part of this SSO Federation
     * 
     * @return an xml representation of web applications that belong to the Single Sign On Federation
     */
    public String getPartnerInfo();
    
    /**
     * Location of the configuration file used to configure the Federation Service
     * 
     * @param confLocation location of the configuration file
     */
    public void setConf(String confLocation);
}
