/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.idm;

import java.io.Serializable;
import java.io.ByteArrayOutputStream;
import java.io.ByteArrayInputStream;
import java.beans.XMLEncoder;
import java.beans.XMLDecoder;

/**
 * Address represents an object to model the Address information associated with an Identity. It contains the basic information.
 * Depending on your application needs, you can extends this class to add more Address specific information
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - May 30, 2006
 *
 */
public class Address implements Serializable
{
	private String street = null;
	private String city = null;
	private String state = null;
	private String country = null;
	private String postalCode = null;
	
    /**
     * Initializes the Address object
     *
     */
	public Address()
	{
		super();
	}
	
    /**
     * Initializes the Address object
     * 
     * @param street 
     * @param city
     * @param state
     * @param postalCode
     * @param country
     */
	public Address(String street,String city,String state,String postalCode,String country)
	{
		this.street = street;
		this.city = city;
		this.state = state;
		this.postalCode = postalCode;
		this.country = country;
	}
	
    /**
     * Returns the street information
     * 
     * @return street information
     */
	public String getStreet()
	{
		return this.street;
	}
	
    /**
     * Sets the street information
     * 
     * @param street street information
     */
	public void setStreet(String street)
	{
		this.street = street;
	}
	
    /**
     * Returns the city information
     * 
     * @return city information
     */
	public String getCity()
	{
		return this.city;
	}
	
    /**
     * Sets the city information
     * 
     * @param city city information
     */
	public void setCity(String city)
	{
		this.city = city;
	}
	
    /**
     * Returns the state information
     * 
     * @return state information
     */
	public String getState()
	{
		return this.state;
	}
	
    /**
     * Sets the state information
     * 
     * @param state state information
     */
	public void setState(String state)
	{
		this.state = state;
	}
	
    /**
     * Returns country information
     * 
     * @return country country information 
     */
	public String getCountry()
	{
		return this.country;
	}
	
    /**
     * Sets country information
     * 
     * @param country country information
     */
	public void setCountry(String country)
	{
		this.country = country;
	}
	
    /**
     * Returns postalCode/zip information
     * 
     * @return postalCode/zip information
     */
	public String getPostalCode()
	{
		return this.postalCode;
	}
	
    /**
     * Sets postalCode/zip information
     * 
     * @param postalCode postalCode/zip information
     */
	public void setPostalCode(String postalCode)
	{
		this.postalCode = postalCode;
	}        
}
