/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package test.jboss.security.federation;

import junit.framework.TestCase;

//commons-http client
import org.apache.commons.httpclient.*;
import org.apache.commons.httpclient.methods.*;
import org.apache.commons.httpclient.cookie.*;
import org.apache.commons.httpclient.protocol.*;
import org.apache.commons.httpclient.contrib.ssl.EasySSLProtocolSocketFactory;

/**
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - Oct 30, 2006
 *
 */
public class SSOTrustServerTestCase extends TestCase 
{                         
    /**
     * 
     * @throws Exception
     */
    public void testValidateSecret() throws Exception
    {
        HttpClient client = new HttpClient();
        
        //setup https protocol setting
        Protocol.registerProtocol("https",new Protocol("https",new EasySSLProtocolSocketFactory(),443));
        
        //get a secret for this identifier
        PostMethod post = new PostMethod("https://node1.jboss.com:8443/federate/trust/generateSecret");
        NameValuePair[] data = {new NameValuePair("identifier","sohil.shah@jboss.com")};
        post.setRequestBody(data);
        String secret = null;
        try
        {
            int statusCode = client.executeMethod(post);
            byte[] response = post.getResponseBody();                       
            secret = new String(response);
            System.out.println("Secret.....");
            System.out.println(secret);
        }
        finally
        {
            if(post != null)
            {
                post.releaseConnection();
            }
        }
                
        //validate the secret
        post = new PostMethod("https://node1.jboss.com:8443/federate/trust/validateSecret");
        NameValuePair[] validateData = {new NameValuePair("identifier","sohil.shah@jboss.com"),new NameValuePair("secret",secret)};
        post.setRequestBody(validateData);        
        try
        {
            int statusCode = client.executeMethod(post);
            byte[] response = post.getResponseBody();                       
            System.out.println("Validation Status..........");
            System.out.println(new String(response));
        }
        finally
        {
            if(post != null)
            {
                post.releaseConnection();
            }
        }
    }
}
